pub enum KeySpace {
User,
Liveliness,
}👎Deprecated:
Use AdvancedPublisher and AdvancedSubscriber instead.
The space of keys to use in a FetchingSubscriber.
This API has been marked as unstable: it works as advertised, but it may be changed in a future release.
Variants
User
👎Deprecated:
Use AdvancedPublisher and AdvancedSubscriber instead.
Liveliness
👎Deprecated:
Use AdvancedPublisher and AdvancedSubscriber instead.